@@ -178,9 +178,15 @@ export default function Toolbar(
   ];
 
   sorter = sorter.concat(toolbarButtons.map((Component, index) => {
-    return {
+    return Component.prototype ? //if is a react component
+    {
       condition: true,
-      dom: <Component mode={mode} state={state} key={index}/>
+      dom: React.createElement(Component, { mode: mode, state: state, key: index })
+    }:
+    {                           //else is a sortable toolbar button
+      index: Component.index,
+      condition: Component.condition,
+      dom: React.createElement( Component.dom, { mode: mode, state: state, key: index })
     };
   }));
 
@@ -219,7 +225,8 @@ Toolbar.propTypes = {
   state: PropTypes.object.isRequired,
   width: PropTypes.number.isRequired,
   height: PropTypes.number.isRequired,
-  allowProjectFileSupport: PropTypes.bool.isRequired
+  allowProjectFileSupport: PropTypes.bool.isRequired,
+  toolbarButtons: PropTypes.array
 };
 
 Toolbar.contextTypes = {
