@@ -1,26 +1,20 @@
-import * as BrowserUtils from './browser';
 import * as GeometryUtils from './geometry';
 import * as GraphInnerCycles from './graph-inner-cycles';
-import * as LayerOperationUtils from './layer-operations';
 import * as MathUtils from './math';
 import * as SnapUtils from './snap';
 import * as SnapSceneUtils from './snap-scene';
 
 export {
-  BrowserUtils,
   GeometryUtils,
   GraphInnerCycles,
-  LayerOperationUtils,
   MathUtils,
   SnapUtils,
   SnapSceneUtils
 };
 
 export default {
-  BrowserUtils,
   GeometryUtils,
   GraphInnerCycles,
-  LayerOperationUtils,
   MathUtils,
   SnapUtils,
   SnapSceneUtils
